@@ -1,7 +1,6 @@
 import json
 import logging
 import os
-import tempfile
 from contextlib import contextmanager
 from copy import deepcopy
 
@@ -10,7 +9,6 @@ import pytest
 import qcodes as qc
 import qcodes.dataset.descriptions.versioning.serialization as serial
 import qcodes.tests.dataset
-from qcodes.configuration import Config
 from qcodes import new_data_set, new_experiment
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
@@ -37,11 +35,9 @@ from qcodes.dataset.sqlite.db_upgrades import (_latest_available_version,
 from qcodes.dataset.sqlite.queries import get_run_description, update_GUIDs
 from qcodes.dataset.sqlite.query_helpers import is_column_in_table, one
 from qcodes.tests.common import error_caused_by
-from qcodes.tests.dataset.temporary_databases import (empty_temp_db,
-                                                      experiment,
-                                                      temporarily_copied_DB)
 from qcodes.dataset.data_set import (
     load_by_counter, load_by_id, load_by_run_spec)
+from qcodes.tests.dataset.conftest import temporarily_copied_DB
 
 fixturepath = os.sep.join(qcodes.tests.dataset.__file__.split(os.sep)[:-1])
 fixturepath = os.path.join(fixturepath, 'fixtures')
@@ -49,19 +45,18 @@ fixturepath = os.path.join(fixturepath, 'fixtures')
 
 @contextmanager
 def location_and_station_set_to(location: int, work_station: int):
-    cfg = Config()
-    old_cfg = deepcopy(cfg.current_config)
+    cfg = qc.config.current_config
+    if cfg is None:
+        raise RuntimeError("Expected config to be not None.")
+    old_cfg = deepcopy(cfg)
     cfg['GUID_components']['location'] = location
     cfg['GUID_components']['work_station'] = work_station
-    cfg.save_to_home()
 
     try:
         yield
 
     finally:
-        cfg.current_config = old_cfg
-        cfg.save_to_home()
-
+        qc.config.current_config = old_cfg
 
 LATEST_VERSION = _latest_available_version()
 VERSIONS = tuple(range(LATEST_VERSION + 1))
@@ -90,37 +85,35 @@ def test_tables_exist(empty_temp_db, version):
     conn.close()
 
 
-def test_initialise_database_at_for_nonexisting_db():
-    with tempfile.TemporaryDirectory() as tmpdirname:
-        db_location = os.path.join(tmpdirname, 'temp.db')
-        assert not os.path.exists(db_location)
+def test_initialise_database_at_for_nonexisting_db(tmp_path):
+    db_location = str(tmp_path / 'temp.db')
+    assert not os.path.exists(db_location)
 
-        initialise_or_create_database_at(db_location)
+    initialise_or_create_database_at(db_location)
 
-        assert os.path.exists(db_location)
-        assert qc.config["core"]["db_location"] == db_location
+    assert os.path.exists(db_location)
+    assert qc.config["core"]["db_location"] == db_location
 
 
-def test_initialise_database_at_for_existing_db():
-    with tempfile.TemporaryDirectory() as tmpdirname:
-        # Define DB location
-        db_location = os.path.join(tmpdirname, 'temp.db')
-        assert not os.path.exists(db_location)
+def test_initialise_database_at_for_existing_db(tmp_path):
+    # Define DB location
+    db_location = str(tmp_path / 'temp.db')
+    assert not os.path.exists(db_location)
 
-        # Create DB file
-        qc.config["core"]["db_location"] = db_location
-        initialise_database()
+    # Create DB file
+    qc.config["core"]["db_location"] = db_location
+    initialise_database()
 
-        # Check if it has been created correctly
-        assert os.path.exists(db_location)
-        assert qc.config["core"]["db_location"] == db_location
+    # Check if it has been created correctly
+    assert os.path.exists(db_location)
+    assert qc.config["core"]["db_location"] == db_location
 
-        # Call function under test
-        initialise_or_create_database_at(db_location)
+    # Call function under test
+    initialise_or_create_database_at(db_location)
 
-        # Check if the DB is still correct
-        assert os.path.exists(db_location)
-        assert qc.config["core"]["db_location"] == db_location
+    # Check if the DB is still correct
+    assert os.path.exists(db_location)
+    assert qc.config["core"]["db_location"] == db_location
 
 
 def test_perform_actual_upgrade_0_to_1():
@@ -577,13 +570,8 @@ def test_update_existing_guids(caplog):
         ds2.mark_started()
         ds2.add_results([{'x': 2}])
 
-        guid_comps_1 = parse_guid(ds1.guid)
-        assert guid_comps_1['location'] == 0
-        assert guid_comps_1['work_station'] == 0
-
-        guid_comps_2 = parse_guid(ds2.guid)
-        assert guid_comps_2['location'] == 0
-        assert guid_comps_2['work_station'] == 0
+        _assert_loc_station(ds1, 0, 0)
+        _assert_loc_station(ds2, 0, 0)
 
     with location_and_station_set_to(0, old_ws):
         ds3 = new_data_set('ds_three')
@@ -591,18 +579,24 @@ def test_update_existing_guids(caplog):
         ds3.mark_started()
         ds3.add_results([{'x': 3}])
 
+        _assert_loc_station(ds3, 0, old_ws)
+
     with location_and_station_set_to(old_loc, 0):
         ds4 = new_data_set('ds_four')
         ds4.set_interdependencies(idps)
         ds4.mark_started()
         ds4.add_results([{'x': 4}])
 
+        _assert_loc_station(ds4, old_loc, 0)
+
     with location_and_station_set_to(old_loc, old_ws):
         ds5 = new_data_set('ds_five')
         ds5.set_interdependencies(idps)
         ds5.mark_started()
         ds5.add_results([{'x': 5}])
 
+        _assert_loc_station(ds5, old_loc, old_ws)
+
     with location_and_station_set_to(new_loc, new_ws):
 
         caplog.clear()
@@ -617,27 +611,20 @@ def test_update_existing_guids(caplog):
             update_GUIDs(ds1.conn)
 
             for record, lvl in zip(caplog.records, expected_levels):
+                print(record)
                 assert record.levelname == lvl
 
-        guid_comps_1 = parse_guid(ds1.guid)
-        assert guid_comps_1['location'] == new_loc
-        assert guid_comps_1['work_station'] == new_ws
+        _assert_loc_station(ds1, new_loc, new_ws)
+        _assert_loc_station(ds2, new_loc, new_ws)
+        _assert_loc_station(ds3, 0, old_ws)
+        _assert_loc_station(ds4, old_loc, 0)
+        _assert_loc_station(ds5, old_loc, old_ws)
 
-        guid_comps_2 = parse_guid(ds2.guid)
-        assert guid_comps_2['location'] == new_loc
-        assert guid_comps_2['work_station'] == new_ws
 
-        guid_comps_3 = parse_guid(ds3.guid)
-        assert guid_comps_3['location'] == 0
-        assert guid_comps_3['work_station'] == old_ws
-
-        guid_comps_4 = parse_guid(ds4.guid)
-        assert guid_comps_4['location'] == old_loc
-        assert guid_comps_4['work_station'] == 0
-
-        guid_comps_5 = parse_guid(ds5.guid)
-        assert guid_comps_5['location'] == old_loc
-        assert guid_comps_5['work_station'] == old_ws
+def _assert_loc_station(ds, expected_loc, expected_station):
+    guid_dict = parse_guid(ds.guid)
+    assert guid_dict["location"] == expected_loc
+    assert guid_dict["work_station"] == expected_station
 
 
 @pytest.mark.parametrize('db_file',
@@ -703,7 +690,7 @@ def test_perform_actual_upgrade_5_to_6():
             assert deser['version'] == 0
 
             desc = serial.from_json_to_current(json_str)
-            assert desc._version == 1
+            assert desc._version == 2
 
 
 def test_perform_upgrade_6_7():
